@@ -8,16 +8,18 @@ from blueflask.lib.errors import unauthorized
 
 from ...consts import SERVICE_CODE
 
+import traceback
+
 
 api = Blueprint('api', __name__, url_prefix='/api/v1')
-__version__ = '1.2'
+__version__ = '1.0'
 
 
 @api.errorhandler(401)
 def unauthorized_error(e):
     return unauthorized(
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-ID')
+        request_id=request.headers.get('X-Request-Id')
         )
 
 
@@ -25,7 +27,7 @@ def unauthorized_error(e):
 def forbidden_error(e):
     return forbidden(
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-ID')
+        request_id=request.headers.get('X-Request-Id')
         )
 
 
@@ -33,7 +35,7 @@ def forbidden_error(e):
 def not_found_error(e):
     return not_found(
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-ID')
+        request_id=request.headers.get('X-Request-Id')
         )
 
 
@@ -41,20 +43,23 @@ def not_found_error(e):
 def method_not_allowed_error(e):
     return not_allowed(
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-ID')
+        request_id=request.headers.get('X-Request-Id')
         )
 
 
 @api.errorhandler(500)
 def internal_server_error(e):
-    msg = 'Please contact API maintainers'
+    message = {
+        'error': str(e),
+        'traceback': ''.join(traceback.format_tb(e.__traceback__))
+        }
     return internal_error(
-        msg,
+        message,
         service_code=SERVICE_CODE,
-        request_id=request.headers.get('X-Request-ID')
+        request_id=request.headers.get('X-Request-Id')
         )
 
 
-from . import async, subscribers, simboxes  # NOQA
+from . import subscribers, simboxes  # NOQA
 
 # EOF
