@@ -10,7 +10,6 @@ from ...core import Client
 from . import api
 
 import pika
-import logging
 import json
 
 
@@ -408,10 +407,10 @@ def delete_subscriber():
     return success(service_code=SERVICE_CODE, message=client.response)
 
 
-@api.route('/subscribers/3g/activate/imsi', methods=['PUT'])
-def update_subscriber_3g():
+@api.route('/subscribers/imsi/<string:service_type>', methods=['PUT'])
+def update_subscriber(service_type):
     """
-    update subscriber 3G in HLR.
+    update subscriber 3G or LTE in HLR.
     ---
     tags:
       - subscribers
@@ -459,190 +458,85 @@ def update_subscriber_3g():
             status:
               type: string
     """
-    client = Client()
+    auth = request.authorization
+    if auth:
+        auth = (auth.username, auth.password)
     data = request.get_json()
-    imsi = data.get('imsi')
-    tplid = data.get('tplid')
-    client.update_tplgprs_profile_3g(imsi, tplid)
-    code = client.response['code']
-    message = client.response['message']
-    return_code = '{service_code}-{code}'.format(
-        service_code=SERVICE_CODE,
-        code=code
-        )
-    if code:
+    params = request.args or {}
+    headers = request.headers or {}
+    document = {
+        'auth': auth or (),
+        'params': params,
+        'headers': headers,
+        'json': data,
+        'service_type': service_type
+        }
+    if service_type == 'activate_3g':
+        condition = (
+          'tplid' not in data or
+          'imsi' not in data
+          )
+    elif service_type == 'activate_lte':
+        condition = (
+          'tplid' not in data or
+          'imsi' not in data or
+          'apntplid' not in data
+          )
+    elif service_type == 'desactivate_lte':
+        condition = (
+          'imsi' not in data
+          )
+    else:
+        return_code = '{service_code}-{code}'.format(
+          service_code=SERVICE_CODE,
+          code=400
+          )
         return internal_error(
-            message=message,
+            message='service_type not define',
             code=return_code,
             service_code=SERVICE_CODE
             )
-    return success(service_code=SERVICE_CODE, message=client.response)
-
-
-@api.route('/subscribers/lte/activate/imsi', methods=['PUT'])
-def update_subscriber_lte():
-    """
-    update subscriber lte in HLR.
-    ---
-    tags:
-      - subscribers
-    components:
-      securitySchemes:
-        basicAuth:
-          type: http
-          scheme: basic
-    security:
-      - basicAuth: []
-    responses:
-      200:
-        description: HLR response
-        schema:
-          id: HLR response
-          properties:
-            code:
-              type: integer
-              description: telnet code
-            data:
-              description: list of infos
-              type: array
-              items:
-                type: string
-            date:
-              description: date of response
-              type: string
-            time:
-              description: time of response
-              type: string
-            message:
-              description: summary of response
-              type: string
-      500:
-        description: internal error
-        schema:
-          id: internal error
-          properties:
-            code:
-              type: integer
-            message:
-              type: string
-            error:
-              type: string
-            status:
-              type: string
-    """
-    client = Client()
-    data = request.get_json()
-    imsi = data.get('imsi')
-    tplid = data.get('tplid')
-    apntplid = data.get('apntplid')
-    client.update_tplgprs_profile_3g(imsi, tplid)
-    code = client.response['code']
-    message = client.response['message']
-    if code == 0:
-        client.update_eps_profile_lte(imsi)
-        code = client.response['code']
-        message = client.response['message']
-        if code == 0:
-            client.update_optgprs_profile_lte(imsi)
-            code = client.response['code']
-            message = client.response['message']
-            if code == 0:
-                client.update_optgprs_profile_lte_confirm(
-                  imsi,
-                  apntplid,
-                  tplid
-                  )
-                code = client.response['code']
-                message = client.response['message']
-    return_code = '{service_code}-{code}'.format(
-        service_code=SERVICE_CODE,
-        code=code
-        )
-    if code:
+    if condition:
+        return_code = '{service_code}-{code}'.format(
+          service_code=SERVICE_CODE,
+          code=400
+          )
         return internal_error(
-            message=message,
+            message='param incorrect',
             code=return_code,
             service_code=SERVICE_CODE
             )
-    return success(service_code=SERVICE_CODE, message=client.response)
-
-
-@api.route('/subscribers/lte/desactivate/imsi', methods=['PUT'])
-def desactivate_subscriber_lte():
-    """
-    desactivate subscriber lte in HLR.
-    ---
-    tags:
-      - subscribers
-    components:
-      securitySchemes:
-        basicAuth:
-          type: http
-          scheme: basic
-    security:
-      - basicAuth: []
-    responses:
-      200:
-        description: HLR response
-        schema:
-          id: HLR response
-          properties:
-            code:
-              type: integer
-              description: telnet code
-            data:
-              description: list of infos
-              type: array
-              items:
-                type: string
-            date:
-              description: date of response
-              type: string
-            time:
-              description: time of response
-              type: string
-            message:
-              description: summary of response
-              type: string
-      500:
-        description: internal error
-        schema:
-          id: internal error
-          properties:
-            code:
-              type: integer
-            message:
-              type: string
-            error:
-              type: string
-            status:
-              type: string
-    """
-    client = Client()
-    data = request.get_json()
-    imsi = data.get('imsi')
-    logging.warn(imsi)
-    client.desactivate_eps_profile_lte(imsi)
-    code = client.response['code']
-    message = client.response['message']
-    if code == 0 or code == 3015:
-        client.desactivate_optgprs_profile_lte(imsi)
-        code = client.response['code']
-        message = client.response['message']
-        if code == 0:
-            client.desactivate_gprs_profile_lte(imsi)
-            code = client.response['code']
-            message = client.response['message']
-    return_code = '{service_code}-{code}'.format(
-        service_code=SERVICE_CODE,
-        code=code
-        )
-    if code:
-        return internal_error(
-            message=message,
-            code=return_code,
-            service_code=SERVICE_CODE
-            )
-    return success(service_code=SERVICE_CODE, message=client.response)
+    else:
+        try:
+            connection = pika.BlockingConnection(
+                pika.ConnectionParameters(
+                    host='localhost',
+                    virtual_host='/hlr'
+                    )
+                )
+        except Exception:
+            # exception de connection lancée par pika
+            # il faut que rabbitmq-server soit installé
+            # et que le vhost /{service} existe déjà
+            return internal_error(
+                message="serveur RabbitMQ injoignable",
+                code='{}-5000'.format(SERVICE_CODE),
+                service_code=SERVICE_CODE
+                )
+        else:
+            channel = connection.channel()
+            channel.exchange_declare(
+                exchange='sendcmd',
+                exchange_type='topic'
+                )
+            # déclaration idempotente: pas grave si l'exchange existe déjà
+            channel.basic_publish(
+                exchange='sendcmd',
+                routing_key='PUT.hlr',
+                body=json.dumps(document),
+                properties=pika.BasicProperties(delivery_mode=2)
+                )
+            connection.close()
+            return success(service_code=SERVICE_CODE)
 
 # EOF
