@@ -31,6 +31,10 @@ elif HOSTNAME.startswith('blst'):
 else:
     APIGW = 'api.blueline.mg'
 
+HLR_ACCOUNTS = [
+    'create_subscriber',
+    'PUT.hlr'
+    ]
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
 
